==> duckscript-0.8.7.tar.gz: duckscript-0.8.7/duckscript_sdk/src/sdk/std/semver/parse/mod.rs <==
use crate::utils::pckg;
use duckscript::types::command::{Command, CommandResult, Commands};
use duckscript::types::instruction::Instruction;
use duckscript::types::runtime::StateValue;
use semver::Version;
use std::collections::HashMap;

#[cfg(test)]
#[path = "./mod_test.rs"]
mod mod_test;

#[derive(Clone)]
pub(crate) struct CommandImpl {
    package: String,
}

impl Command for CommandImpl {
    fn name(&self) -> String {
        pckg::concat(&self.package, "Parse")
    }

    fn aliases(&self) -> Vec<String> {
        vec!["semver_parse".to_string()]
    }

    fn help(&self) -> String {
        include_str!("help.md").to_string()
    }

    fn clone_and_box(&self) -> Box<dyn Command> {
        Box::new((*self).clone())
    }

    fn requires_context(&self) -> bool {
        true
    }

    fn run_with_context(
        &self,
        arguments: Vec<String>,
        _state: &mut HashMap<String, StateValue>,
        variables: &mut HashMap<String, String>,
        output_variable: Option<String>,
        _instructions: &Vec<Instruction>,
        _commands: &mut Commands,
        _line: usize,
    ) -> CommandResult {
        if arguments.is_empty() {
            CommandResult::Error("No semver value provided.".to_string())
        } else {
            match Version::parse(&arguments[0]) {
                Ok(version) => match output_variable {
                    Some(name) => {
                        variables.insert(
                            format!("{}.major", &name).to_string(),
                            version.major.to_string(),
                        );
                        variables.insert(
                            format!("{}.minor", &name).to_string(),
                            version.minor.to_string(),
                        );
                        variables.insert(
                            format!("{}.patch", &name).to_string(),
                            version.patch.to_string(),
                        );

                        CommandResult::Continue(None)
                    }
                    None => CommandResult::Continue(None),
                },
                Err(error) => CommandResult::Error(error.to_string()),
            }
        }
    }
}

pub(crate) fn create(package: &str) -> Box<dyn Command> {
    Box::new(CommandImpl {
        package: package.to_string(),
    })
}

==> duckscript-0.11.1.tar.gz: duckscript-0.11.1/duckscript_sdk/src/sdk/std/semver/parse/mod.rs <==
use crate::utils::pckg;
use duckscript::types::command::{Command, CommandInvocationContext, CommandResult};
use semver::Version;

#[cfg(test)]
#[path = "./mod_test.rs"]
mod mod_test;

#[derive(Clone)]
pub(crate) struct CommandImpl {
    package: String,
}

impl Command for CommandImpl {
    fn name(&self) -> String {
        pckg::concat(&self.package, "Parse")
    }

    fn aliases(&self) -> Vec<String> {
        vec!["semver_parse".to_string()]
    }

    fn help(&self) -> String {
        include_str!("help.md").to_string()
    }

    fn clone_and_box(&self) -> Box<dyn Command> {
        Box::new((*self).clone())
    }

    fn run(&self, context: CommandInvocationContext) -> CommandResult {
        if context.arguments.is_empty() {
            CommandResult::Error("No semver value provided.".to_string())
        } else {
            match Version::parse(&context.arguments[0]) {
                Ok(version) => match context.output_variable {
                    Some(name) => {
                        context.variables.insert(
                            format!("{}.major", &name).to_string(),
                            version.major.to_string(),
                        );
                        context.variables.insert(
                            format!("{}.minor", &name).to_string(),
                            version.minor.to_string(),
                        );
                        context.variables.insert(
                            format!("{}.patch", &name).to_string(),
                            version.patch.to_string(),
                        );

                        CommandResult::Continue(None)
                    }
                    None => CommandResult::Continue(None),
                },
                Err(error) => CommandResult::Error(error.to_string()),
            }
        }
    }
}

pub(crate) fn create(package: &str) -> Box<dyn Command> {
    Box::new(CommandImpl {
        package: package.to_string(),
    })
}
